<?php

/**
  * Homepage preferences tab for admin panel, AdminHomepage.php
  * @category admin
  *
  * @author PrestaShop <support@prestashop.com>
  * @copyright PrestaShop
  * @license http://www.opensource.org/licenses/osl-3.0.php Open-source licence 3.0
  * @version 0.8
  *
  */
  
include_once(dirname(__FILE__).'/AdminPreferences.php');

class AdminAppearance extends AdminTab
{
	public function __construct()
	{
		$this->className = 'Configuration';
		$this->table = 'configuration';
 		
 		$this->_fieldsLang = array(
			'PS_META_TITLE' => 'isGenericName',
			'PS_META_DESCRIPTION' => 'isGenericName',
			'PS_META_KEYWORDS' => 'isGenericName'
		);
	
		parent::__construct();
	}
	
	public function postProcess()
	{
	 	global $currentIndex;

		if (isset($_POST['submitHomepage'.$this->table]))
		{
		 	/* Language() instance determined by default language */
			$defaultLanguage = new Language(intval(Configuration::get('PS_LANG_DEFAULT')));
			
			/* All availables languages */
			$languages = Language::getLanguages();		
			
			foreach ($this->_fieldsLang AS $fieldLang => $rule)
				foreach ($languages AS $language)
					if (Tools::getValue($fieldLang.'_'.$language['id_lang']))
						if (!Validate::$rule(Tools::getValue($fieldLang.'_'.$language['id_lang'])))
							$this->_errors[] = 'field <b>'.$fieldLang.' ('.$language['name'].' language)</b> is invalid';
			
			if (!sizeof($this->_errors))
			{
				foreach ($this->_fieldsLang AS $fieldLang => $rule)
					foreach ($languages AS $language)
						$configurations[$fieldLang][$language['id_lang']] = Tools::getValue($fieldLang.'_'.$language['id_lang']);
				foreach ($configurations AS $key => $val)
					Configuration::updateValue($key, $val);
				
				if (isset($_FILES['PS_LOGO']['tmp_name']) AND $_FILES['PS_LOGO']['tmp_name'])
				{
					if ($error = checkImage($_FILES['PS_LOGO'], 300000))
						$this->_errors[] = $error;
					elseif (!imageResize($_FILES['PS_LOGO'], _PS_IMG_DIR_.'logo.jpg'))
						$this->_errors[] = 'an error occured during logo copy';
				}
				
				$this->uploadIco('PS_FAVICON', _PS_THEME_DIR_.'img/favicon.ico');

				if (!sizeof($this->_errors))
					Tools::redirectAdmin($currentIndex.'&conf=6');
			}
		}
	}

	public function display()
	{
		header('Cache-Control: no-cache, must-revalidate');
		header('Expires: Mon, 26 Jul 1997 05:00:00 GMT');
		$this->displayForm();
	}
	
	public function gFieldValue($id_lang, $field, $confValues)
	{
		if ($value = Tools::getValue($field.'_'.intval($id_lang)))
			return $value;
		elseif (isset($confValues[intval($id_lang)][$field]))
			return $confValues[intval($id_lang)][$field];
		else
			return false;			
	}
	
	public function displayForm()
	{
		global $currentIndex;
			
		$defaultLanguage = intval(Configuration::get('PS_LANG_DEFAULT'));
		$languages = Language::getLanguages();
		$obj = $this->loadObject(true);
		$divLangName = 'PS_META_TITLE¤PS_META_DESCRIPTION¤PS_META_KEYWORDS';
		
		foreach ($this->_fieldsLang AS $key => $value)
			$getConf[] = $key;
		$confValues = Configuration::getMultipleInt($getConf);

		echo '
		<script type="text/javascript">
			id_language = Number('.$defaultLanguage.');
		</script>
		<form action="'.$currentIndex.'&submitAdd'.$this->table.'=1" method="post" enctype="multipart/form-data">
			<fieldset class="width3"><legend><img src="../img/t/38.gif" />'.$this->l('Appearance').'</legend>
				<label>'.$this->l('Header logo:').' </label>
				<div class="margin-form">
					'.(file_exists(_PS_IMG_DIR_.'logo.jpg') ? '<img src="../img/logo.jpg" alt="'.$this->l('Logo').'" title="'.$this->l('Logo').'" /><br />' : '').'
					<input type="file" name="PS_LOGO" />
					<p style="clear: both">'.$this->l('Will appear on page and e-mail headers').'<br />(230px * 75px '.$this->l('approximately').')</p>
				</div>
				<label>'.$this->l('Favicon:').' </label>
				<div class="margin-form">
					<input type="file" name="PS_FAVICON" />
					<p style="clear: both"><img src="'._THEME_IMG_DIR_.'favicon.ico" alt="'.$this->l('Favicon').'" title="'.$this->l('Favicon').'" style="float:left;" />'.$this->l('The favicon used by your shop.').'<br />'.$this->l('Need an icon file (favicon.ico).').'</p>
				</div>
				<label>'.$this->l('Meta title:').' </label>
				<div class="margin-form">';
				foreach ($languages as $language)
					echo '
					<div id="PS_META_TITLE_'.$language['id_lang'].'" style="display: '.($language['id_lang'] == $defaultLanguage ? 'block' : 'none').'; float: left;">
						<input type="text" name="PS_META_TITLE_'.$language['id_lang'].'" value="'.$this->gFieldValue(intval($language['id_lang']), 'PS_META_TITLE', $confValues).'" />
					</div>';
				displayFlags($languages, $defaultLanguage, $divLangName, 'PS_META_TITLE');
				echo '<p class="clear">&nbsp;</p>
				</div>
				<label>'.$this->l('Meta description:').' </label>
				<div class="margin-form">';
				foreach ($languages as $language)
					echo '
					<div id="PS_META_DESCRIPTION_'.$language['id_lang'].'" style="display: '.($language['id_lang'] == $defaultLanguage ? 'block' : 'none').'; float: left; vertical-align: top;">
						<input type="text" name="PS_META_DESCRIPTION_'.$language['id_lang'].'" value="'.$this->gFieldValue(intval($language['id_lang']), 'PS_META_DESCRIPTION', $confValues).'" />
					</div>';
				displayFlags($languages, $defaultLanguage, $divLangName, 'PS_META_DESCRIPTION');
				echo '<p class="clear">&nbsp;</p>
				</div>
				<label>'.$this->l('Meta keywords:').' </label>
				<div class="margin-form">';
				foreach ($languages as $language)
					echo '
					<div id="PS_META_KEYWORDS_'.$language['id_lang'].'" style="display: '.($language['id_lang'] == $defaultLanguage ? 'block' : 'none').'; float: left; vertical-align: top;">
						<input type="text" name="PS_META_KEYWORDS_'.$language['id_lang'].'" value="'.$this->gFieldValue(intval($language['id_lang']), 'PS_META_KEYWORDS', $confValues).'" />
					</div>';
				displayFlags($languages, $defaultLanguage, $divLangName, 'PS_META_KEYWORDS');
				echo '<p class="clear">&nbsp;</p>
				</div>
				<div class="margin-form">
					<input type="submit" value="'.$this->l('   Save   ').'" name="submitHomepage'.$this->table.'" class="button" />
				</div>
			</fieldset>
		</form>';
	}
}

?>